-- 消息持久化数据表
CREATE TABLE webchat_ugc.`web_chat_message` (
     `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
     `sender` char(100) NOT NULL COMMENT '发送人',
     `receiver` char(100) NOT NULL COMMENT '接收人',
     `proxy_sender` char(100) DEFAULT NULL COMMENT '消息代理发送人（应用在群聊场景）',
     `message` text DEFAULT NULL COMMENT '消息内容',
     `image` varchar(300) DEFAULT NULL COMMENT '图片',
     `type` tinyint(1) DEFAULT 0 COMMENT '消息类型',
     `IS_READ` tinyint(1) DEFAULT 0 COMMENT '是否已读',
     `SEND_DATE` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '消息时间',
     `UPDATE_DATE` datetime DEFAULT NULL COMMENT '更新时间',
     `VERSION` int DEFAULT '0' COMMENT '版本',
     PRIMARY KEY (`ID`),
     KEY `INDEX_SENDER_PROXY_SENDER` (`sender`, `proxy_sender`),
     KEY `INDEX_RECEIVER` (`receiver`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='消息持久化数据表';


-- 红包信息表
CREATE TABLE webchat_ugc.`web_chat_red_packet` (
       `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
       `order_id` char(64) NOT NULL COMMENT '支付平台交易订单id',
       `sender` char(100) NOT NULL COMMENT '红包发送人',
       `receiver` char(100) NOT NULL COMMENT '接受账户（人、群、企业账户）',
       `type` int(4) NOT NULL COMMENT '红包类型 1 固定红包、2 拼手气',
       `count` int(4) NOT NULL COMMENT '红包个数',
       `cover` varchar(100) DEFAULT NULL COMMENT '红包封面',
       `blessing` varchar(50) DEFAULT NULL COMMENT '祝福语',
       `status` int(4) NOT NULL COMMENT '状态',
       `total_money` DECIMAL(10, 2) default '0.00' COMMENT '金额',
       `CREATE_BY` char(100) DEFAULT NULL COMMENT '创建人',
       `CREATE_DATE` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
       `expire_date` datetime NOT NULL COMMENT '过期时间',
       `UPDATE_BY` char(100) DEFAULT NULL COMMENT '更新人',
       `UPDATE_DATE` datetime DEFAULT NULL COMMENT '更新时间',
       `VERSION` int DEFAULT '0' COMMENT '版本',
       PRIMARY KEY (`ID`),
       KEY `INDEX_ORDER_ID` (`order_id`),
       KEY `INDEX_SENDER` (`sender`),
       KEY `INDEX_STATUS_EXPIRE_DATE` (`status`, `expire_date`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COMMENT='红包信息表';

-- 红包拆分记录明细表
CREATE TABLE webchat_ugc.`web_chat_red_packet_record` (
      `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
      `red_packet_id` bigint NOT NULL COMMENT '红包id',
      `user_id` char(100) NOT NULL COMMENT '领取人',
      `money` DECIMAL(10, 2) default '0.00' COMMENT '领取金额',
      `CREATE_DATE` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
      PRIMARY KEY (`ID`),
      KEY `INDEX_RED_PACKET_ID` (`red_packet_id`),
      KEY `INDEX_USER_ID` (`user_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='红包拆分记录明细表';


-- webchat朋友圈动态核心数据表
CREATE TABLE webchat_ugc.`web_chat_moment` (
        `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
        `author` char(100) NOT NULL COMMENT '动态作者 ',
        `content` varchar(300) DEFAULT NULL COMMENT '正文（纯文本）',
        `status` int(4) NOT NULL DEFAULT 1 COMMENT '状态',
        `include_images` tinyint(1) DEFAULT 0 COMMENT '是否包含图片，冗余字段',
        `include_video` tinyint(1) DEFAULT 0 COMMENT '是否包含图片，冗余字段',
        `include_link` tinyint(1) DEFAULT 0 COMMENT '是否包含连接，冗余字段',
        `ip` char(30) DEFAULT NULL COMMENT 'IP',
        `ip_address` varchar(100) DEFAULT NULL COMMENT 'IP归属地',
        `review_score` int(4) DEFAULT NULL COMMENT '大模型机审内容质量分',
        `CREATE_DATE` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
        `UPDATE_BY` char(100) DEFAULT NULL COMMENT '更新人',
        `UPDATE_DATE` datetime DEFAULT NULL COMMENT '更新时间',
       PRIMARY KEY (`ID`),
       KEY `INDEX_AUTHOR_STATUS` (`author`, `status`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COMMENT='webchat朋友圈动态核心数据表';

-- webchat朋友圈动态媒体资源表
CREATE TABLE webchat_ugc.`web_chat_moment_media` (
                                                     `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
                                                     `moment_id` bigint unsigned NOT NULL COMMENT '动态ID',
                                                     `type` int(4) NOT NULL COMMENT '资源类型 1图片 2视频',
                                                     `resource` varchar(300) NOT NULL COMMENT '资源地址，对应OS存储资源URL',
                                                     `size` bigint unsigned DEFAULT 0 COMMENT '资源大小',
                                                     `width` int(6) DEFAULT 0 COMMENT '资源宽度',
                                                     `height` int(6) DEFAULT 0 COMMENT '资源高度',
                                                     PRIMARY KEY (`ID`),
                                                     KEY `INDEX_MOMENT_ID_TYPE` (`moment_id`, `type`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='webchat朋友圈动态媒体资源表';

-- webchat朋友圈动态分享链接表
CREATE TABLE webchat_ugc.`web_chat_moment_link` (

                                                    `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
                                                    `moment_id` bigint unsigned NOT NULL COMMENT '动态ID',
                                                    `resource` varchar(300) NOT NULL COMMENT '分享到朋友圈的url网络资源链接',
                                                    `title` varchar(100) DEFAULT NULL COMMENT '链接解析标题',
                                                    `cover` varchar(300) DEFAULT NULL COMMENT '链接解析封面图，webchat OS地址',
                                                    PRIMARY KEY (`ID`),
                                                    UNIQUE KEY `INDEX_MOMENT_ID` (`moment_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8mb4 COMMENT='webchat朋友圈动态分享链接表';


-- 朋友圈动态时间线
CREATE TABLE webchat_ugc.`web_chat_moment_timeline_0`(
                                                         `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
                                                         `user_id` char(100) NOT NULL COMMENT '谁的时间线',
                                                         `moment_id` bigint unsigned NOT NULL COMMENT '动态id',
                                                         `time_line` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '时间线时间点',
                                                         PRIMARY KEY (`ID`),
                                                         KEY `INDEX_USER_ID_TIME_LINE` (`user_id`, `time_line`),
                                                         KEY `INDEX_MOMENT_ID` (`moment_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='webchat朋友圈时间线';

CREATE TABLE webchat_ugc.`web_chat_moment_timeline_1`(
                                                         `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
                                                         `user_id` char(100) NOT NULL COMMENT '谁的时间线',
                                                         `moment_id` bigint unsigned NOT NULL COMMENT '动态id',
                                                         `time_line` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '时间线时间点',
                                                         PRIMARY KEY (`ID`),
                                                         KEY `INDEX_USER_ID_TIME_LINE` (`user_id`, `time_line`),
                                                         KEY `INDEX_MOMENT_ID` (`moment_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='webchat朋友圈时间线';

CREATE TABLE webchat_ugc.`web_chat_moment_timeline_2`(
                                                         `ID` bigint unsigned NOT NULL AUTO_INCREMENT COMMENT '自增ID',
                                                         `user_id` char(100) NOT NULL COMMENT '谁的时间线',
                                                         `moment_id` bigint unsigned NOT NULL COMMENT '动态id',
                                                         `time_line` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '时间线时间点',
                                                         PRIMARY KEY (`ID`),
                                                         KEY `INDEX_USER_ID_TIME_LINE` (`user_id`, `time_line`),
                                                         KEY `INDEX_MOMENT_ID` (`moment_id`)
) ENGINE=InnoDB AUTO_INCREMENT=1 DEFAULT CHARSET=utf8 COMMENT='webchat朋友圈时间线';